@@ -12,11 +12,12 @@ from SharedData.SharedDataAWSS3 import S3SyncDownloadMetadata,S3Upload
 
 class Metadata():
     
-    def __init__(self, name, mode='rw', sync_frequency_days=0.5):
-        if Logger.log is None:            
+    def __init__(self, name, mode='rw', sync_frequency_days=0.5, user='master'):
+        if Logger.log is None:
             Logger('Metadata')
 
-        Logger.log.debug('Initializing Metadata %s,%s ...' % (name,mode))
+        Logger.log.debug('Initializing Metadata %s,%s,%s ...' % (user,name,mode))
+        self.user = user
         
         self.s3read = False
         self.s3write = False
@@ -28,14 +29,14 @@ class Metadata():
             self.s3write = True
         elif mode == 'rw':
             self.s3read = True
-            self.s3write = True
+            self.s3write = True        
 
         self.name = name
         self.xls = {}
         self.static = pd.DataFrame([])        
         self.symbols = pd.DataFrame([],dtype=str)
         self.series = pd.Series([],dtype=str)
-        self.fpath = Path(os.environ['DATABASE_FOLDER'])
+        self.fpath = Path(os.environ['DATABASE_FOLDER']) / user
 
         self.pathxls = self.fpath /  ('Metadata/'+name+'.xlsx')
         self.pathpkl = self.fpath /  ('Metadata/'+name+'.pkl')
@@ -45,7 +46,7 @@ class Metadata():
         if (self.s3read):
 
             self.lastsync = pd.DataFrame([])
-            self.lastsyncfpath = Path(os.environ['DATABASE_FOLDER']) / ('Metadata/lastsync.txt')
+            self.lastsyncfpath = Path(os.environ['DATABASE_FOLDER']) / (user+'/Metadata/lastsync.txt')
             if self.lastsyncfpath.is_file():
                 self.lastsync = pd.read_csv(self.lastsyncfpath)
                 self.lastsync = self.lastsync.set_index('file')
