@@ -98,12 +98,12 @@ class KinesisLogStreamConsumer():
         self.dflogs = pd.DataFrame([])
         if self.logfilepath.is_file():
             self.dflogs = pd.read_csv(self.logfilepath,header=None,sep=';',\
-                error_bad_lines=False, engine='c')
+                engine='python',error_bad_lines=False,warn_bad_lines=False)
             self.dflogs.columns = ['shardid','sequence_number','user_name','asctime','logger_name','level','message']
         
         if self.lastlogfilepath.is_file():
             _dflogs = pd.read_csv(self.lastlogfilepath,header=None,sep=';',\
-                error_bad_lines=False, engine='c')
+                engine='python',error_bad_lines=False,warn_bad_lines=False)
             _dflogs.columns = ['shardid','sequence_number','user_name','asctime','logger_name','level','message']
             self.dflogs = pd.concat([_dflogs,self.dflogs],axis=0)
 
