@@ -23,7 +23,7 @@ def S3SyncDownloadDataFrame(path,shm_name):
     env['PATH'] = sys.exec_prefix+r'\Scripts'
 
     process = subprocess.Popen(['aws','s3','sync',awsfolder,dbfolder,\
-        '--profile','s3readonly',\
+        '--profile',Logger.user,\
         '--exclude','*',\
         '--include',shm_name.split('/')[-1]+'.json',\
         '--include',shm_name.split('/')[-1]+'.npy'],\
@@ -41,9 +41,10 @@ def S3SyncDownloadDataFrame(path,shm_name):
     rc = process.poll()
     success= rc==0
     if success:
-        Logger.log.debug('AWS S3 Sync DataFrame %s DONE!' % (shm_name))
+        Logger.log.debug('AWS S3 Sync DataFrame %s,%s DONE!' % (Logger.user,shm_name))
     else:
-        Logger.log.error('AWS S3 Sync DataFrame %s ERROR!' % (shm_name))
+        Logger.log.error('AWS S3 Sync DataFrame %s,%s ERROR!' % (Logger.user,shm_name))
+        Logger.log.error('AWS S3 Sync DataFrame \"%s\"' % (''.join(process.stderr.readlines())))
     return success
 
 def S3SyncDownloadTimeSeries(path,shm_name):    
@@ -52,7 +53,7 @@ def S3SyncDownloadTimeSeries(path,shm_name):
     env = os.environ.copy()
     env['PATH'] = sys.exec_prefix+r'\Scripts'
     process = subprocess.Popen(['aws','s3','sync',awsfolder,path,\
-        '--profile','s3readonly',\
+        '--profile',Logger.user,\
         #'--delete',\
         '--exclude=shm_info.json'],\
         stdout=subprocess.PIPE, stderr=subprocess.PIPE,\
@@ -69,9 +70,10 @@ def S3SyncDownloadTimeSeries(path,shm_name):
     rc = process.poll()
     success= rc==0
     if success:
-        Logger.log.debug('AWS S3 Sync timeseries %s DONE!' % (shm_name))
+        Logger.log.debug('AWS S3 Sync timeseries %s,%s DONE!' % (Logger.user,shm_name))
     else:
-        Logger.log.error('AWS S3 Sync timeseries %s ERROR!' % (shm_name))
+        Logger.log.error('AWS S3 Sync timeseries %s,%s ERROR!' % (Logger.user,shm_name))
+        Logger.log.error('AWS S3 Sync timeseries \"%s\"' % (''.join(process.stderr.readlines())))
     return success
 
 def S3SyncDownloadMetadata(pathpkl,name):
@@ -88,7 +90,7 @@ def S3SyncDownloadMetadata(pathpkl,name):
     env['PATH'] = sys.exec_prefix+r'\Scripts'
 
     process = subprocess.Popen(['aws','s3','sync',awsfolder,dbfolder,\
-        '--profile','s3readonly',\
+        '--profile',Logger.user,\
         '--exclude','*',\
         '--include',name.split('/')[-1]+'.pkl',\
         '--include',name.split('/')[-1]+'_SYMBOLS.pkl',\
@@ -109,9 +111,9 @@ def S3SyncDownloadMetadata(pathpkl,name):
     rc = process.poll()
     success= rc==0
     if success:
-        Logger.log.debug('AWS S3 Sync download metadata %s DONE!' % (name))
+        Logger.log.debug('AWS S3 Sync download metadata %s,%s DONE!' % (Logger.user,name))
     else:
-        Logger.log.error('AWS S3 Sync download metadata %s ERROR!' % (name))
+        Logger.log.error('AWS S3 Sync download metadata %s,%s ERROR!' % (Logger.user,name))
         Logger.log.error('AWS S3 Sync download metadata \"%s\"' % (''.join(process.stderr.readlines())))
     return success
 
@@ -121,12 +123,12 @@ def S3Upload(localfilepath):
     remotefilepath = remotefilepath.replace('\\','/')        
     localfilepath = str(localfilepath).replace('\\','/')              
       
-    Logger.log.debug('Uploading to S3 '+str(localfilepath)+' ...')
+    Logger.log.debug(Logger.user+' Uploading to S3 '+str(localfilepath)+' ...')
     try:                
-        session = boto3.Session(profile_name='s3readwrite')   
+        session = boto3.Session(profile_name=Logger.user)   
         s3 = session.resource('s3')
         bucket = s3.Bucket(os.environ['S3_BUCKET'].replace('s3://',''))
         bucket.upload_file(localfilepath,remotefilepath.replace(os.environ['S3_BUCKET'],'')[1:])
-        Logger.log.debug('Uploading to S3 '+str(localfilepath)+' DONE!')
+        Logger.log.debug(Logger.user+' Uploading to S3 '+str(localfilepath)+' DONE!')
     except Exception as e:
-        Logger.log.error('Uploading to S3 '+localfilepath+' ERROR! %s' % str(e))        
\ No newline at end of file
+        Logger.log.error(Logger.user+' Uploading to S3 '+localfilepath+' ERROR! %s' % str(e))
\ No newline at end of file
