@@ -42,20 +42,22 @@ class SharedDataFrame:
                 if self.sharedData.s3read:
                     #Synchronize S3                
                     path, shm_name = self.getDataPath()
+
                     # Sync download S3 files
+                    sync = False
                     lastsync = self.sharedData.lastsync
                     if not shm_name in lastsync.index:
+                        sync = True
+                    else:
+                        td = (datetime.utcnow() - lastsync['timestamp'][shm_name]).seconds/86400
+                        if td>self.sharedData.sync_frequency_days:
+                            sync=True
+                                                            
+                    if sync:
                         if S3SyncDownloadDataFrame(path, shm_name):
                             lastsync.loc[shm_name,'timestamp'] = datetime.utcnow()
                             lastsync.index.name = 'file'
                             lastsync.to_csv(self.sharedData.lastsyncfpath)
-                    else:
-                        td = (datetime.utcnow() - lastsync['timestamp'][shm_name]).seconds/86400
-                        if td>self.sharedData.sync_frequency_days:
-                            if S3SyncDownloadDataFrame(path, shm_name):
-                                lastsync.loc[shm_name,'timestamp'] = datetime.utcnow()
-                                lastsync.index.name = 'file'
-                                lastsync.to_csv(self.sharedData.lastsyncfpath)       
                     
                     # Read
                     df = self.Read()
@@ -77,7 +79,10 @@ class SharedDataFrame:
         shm_name = shm_name.replace('\\','/')
 
         path = Path(os.environ['DATABASE_FOLDER'])
-        path = path / shm_name
+        path = path / self.sharedData.user
+        path = path / self.sharedData.database
+        path = path / self.sharedDataFeeder.feeder
+        path = path / self.period       
         path = Path(str(path).replace('\\','/'))
         if not os.path.isdir(path):
             os.makedirs(path)
