@@ -67,20 +67,19 @@ class SharedDataRealTime:
     
     def Subscribe(shdata):
         today = pd.Timestamp(pd.Timestamp.now().date())
-        wd = shdata['RT/Watchdog']['D1']
-        if not wd.exists(today):
+        wd = shdata['WATCHDOG']['D1']
+        dfwatchdog = wd[today]
+        if dfwatchdog.empty:
             df = pd.DataFrame(
                 0,
-                index = ['MarketData','Signals','Porfolios'],
+                index = [shdata.database],
                 columns = ['watchdog']
             )
-            df.loc[shdata.database,'watchdog'] = time.time() - 20
-            wd[today] = df
-            wd.tags[today].Write()
+            dfwatchdog = df
         
         # start subprocess if 
-        df = wd[today]
-        if time.time() - df.loc[shdata.database,'watchdog'] > 15:
+        if time.time() - dfwatchdog.loc[shdata.database,'watchdog'] > 15:
+            Logger.log.debug('Starting new real time consumer process for %s' % (shdata.database))
             proc = subprocess.Popen(['python','-m',\
                 'SharedData.SharedDataRealTimeProcess',\
                 shdata.database],
@@ -88,6 +87,8 @@ class SharedDataRealTime:
                 universal_newlines=True, shell=True)
             rc = proc.poll()
             return (rc is None)
+        else:
+            Logger.log.debug('Real time consumer process for %s already exists' % (shdata.database))
         
         #success
         return True
